@@ -197,12 +197,13 @@ class PithosRestClient(TestCase):
     @patch('%s.set_header' % rest_pkg)
     @patch('%s.get' % rest_pkg, return_value=FR())
     def test_account_get(self, get, SH, SP):
-        keys = ('limit', 'marker', 'format', 'shared', 'until')
+        keys = ('limit', 'marker', 'format', 'shared', 'public', 'until')
         for params in product(
                 (None, 42),
                 (None, 'X'),
                 ('json', 'xml'),
                 (False, True),
+                (False, True),
                 (None, '50m3-d473'),
                 (None, '50m3-07h3r-d473'),
                 (None, 'y37-4n7h3r-d473'),
@@ -211,11 +212,10 @@ class PithosRestClient(TestCase):
             args, kwargs = params[-2], params[-1]
             params = params[:-2]
             self.client.account_get(*(params + args), **kwargs)
-            self.assertEqual(SP.mock_calls[-5:],
-                [call(keys[i], iff=X) if (
-                    i == 3) else call(
-                        keys[i], X, iff=X) for i, X in enumerate(params[:5])])
-            IMS, IUS = params[5], params[6]
+            self.assertEqual(SP.mock_calls[-6:],
+                [call(keys[i], iff=X) if (i in (3, 4)) else call(
+                    keys[i], X, iff=X) for i, X in enumerate(params[:6])])
+            IMS, IUS = params[6], params[7]
             self.assertEqual(SH.mock_calls[-2:], [
                 call('If-Modified-Since', IMS),
                 call('If-Unmodified-Since', IUS)])
@@ -242,7 +242,7 @@ class PithosRestClient(TestCase):
             pm = pm[:-2]
             self.client.account_post(*(pm + args), **kwargs)
             upd = pm[0]
-            self.assertEqual(SP.mock_calls[-1], call('update', iff=upd))
+            self.assertEqual(SP.mock_calls[-1], call('update', '', iff=upd))
             expected = []
             if pm[1]:
                 expected += [
@@ -297,6 +297,7 @@ class PithosRestClient(TestCase):
                 ('json', 'some-format'),
                 ([], ['k1', 'k2', 'k3']),
                 (False, True),
+                (False, True),
                 (None, 'unt1l-d473'),
                 (None, 'y37-4n47h3r'),
                 (None, '4n47h3r-d473'),
@@ -305,12 +306,15 @@ class PithosRestClient(TestCase):
             args, kwargs = pm[-2:]
             pm = pm[:-2]
             self.client.container_get(*(pm + args), **kwargs)
-            lmt, mrk, prfx, dlm, path, frmt, meta, shr, unt = pm[:-2]
+            lmt, mrk, prfx, dlm, path, frmt, meta, shr, pbl, unt = pm[:-2]
             exp = [call('limit', lmt, iff=lmt), call('marker', mrk, iff=mrk)]
             exp += [call('path', path)] if path else [
                 call('prefix', prfx, iff=prfx),
                 call('delimiter', dlm, iff=dlm)]
-            exp += [call('format', frmt, iff=frmt), call('shared', iff=shr)]
+            exp += [
+                call('format', frmt, iff=frmt),
+                call('shared', iff=shr),
+                call('public', iff=pbl)]
             if meta:
                 exp += [call('meta', ','.join(meta))]
             exp += [call('until', unt, iff=unt)]
@@ -369,7 +373,7 @@ class PithosRestClient(TestCase):
             self.client.container_post(*(pm + args), **kwargs)
             upd, frmt = pm[:2]
             self.assertEqual(SP.mock_calls[-2:], [
-                call('update', iff=upd),
+                call('update', '', iff=upd),
                 call('format', frmt, iff=frmt)])
             qta, vrs, metas, ctype, clen, trenc = pm[2:]
             prfx = 'X-Container-Meta-'
@@ -637,7 +641,9 @@ class PithosRestClient(TestCase):
                     if pval:
                         perm_str += ';' if perm_str else ''
                         perm_str += '%s=%s' % (ptype, ','.join(pval))
-                exp += [call('X-Object-Sharing', perm_str)]
+                exp += [call('X-Object-Sharing', perm_str, iff=perms)]
+            else:
+                exp += [call('X-Object-Sharing', '', iff={})]
             exp += [call('X-Object-Public', public, public is not None)]
             for k, v in metas.items():
                 exp += [call('X-Object-Meta-%s' % k, v)]
@@ -674,7 +680,7 @@ class PithosRestClient(TestCase):
             format, update = pm[:2]
             self.assertEqual(SP.mock_calls[-2:], [
                 call('format', format, iff=format),
-                call('update', iff=update)])
+                call('update', '', iff=update)])
             (
                 im, inm, clen, ctype, crng, trenc, cenc,
                 condis, srcobj, srcacc, srcvrs, obytes, mnfs) = terms
@@ -699,7 +705,9 @@ class PithosRestClient(TestCase):
                     if pval:
                         perm_str += ';' if perm_str else ''
                         perm_str += '%s=%s' % (ptype, ','.join(pval))
-                exp += [call('X-Object-Sharing', perm_str)]
+                exp += [call('X-Object-Sharing', perm_str, iff=perms)]
+            else:
+                exp += [call('X-Object-Sharing', '', iff={})]
             exp += [call('X-Object-Public', public, public is not None)]
             for k, v in metas.items():
                 exp += [call('X-Object-Meta-%s' % k, v)]
@@ -737,6 +745,26 @@ class PithosRestClient(TestCase):
                 **kwargs))
 
 
+class PithosMethods(TestCase):
+
+    def test__range_up(self):
+        from kamaki.clients.pithos import _range_up
+        for args, expected in (
+                ((0, 100, 1000, '10'), '0-10'),
+                ((0, 100, 1000, '-10'), ''),
+                ((900, 1000, 1000, '-10'), '990-1000'),
+                ((150, 250, 1000, '10'), ''),
+                ((10, 200, 1000, '130-170'), '130-170'),
+                ((150, 200, 1000, '130-170'), '150-170'),
+                ((100, 150, 1000, '130-170'), '130-150'),
+                ((200, 250, 1000, '130-170'), ''),
+                ((100, 250, 1000, '30-170,200-270'), '100-170,200-250'),
+                ((40, 950, 1000, '-170,200-270,50',), '830-950,200-270,40-50'),
+                ((740, 900, 1000, '-170,200-270,50',), '830-900'),
+                ((42, 333, 800, '100,50-200,-600',), '42-100,50-200,200-333')):
+            self.assertEqual(_range_up(*args), expected)
+
+
 class PithosClient(TestCase):
 
     files = []
@@ -1028,7 +1056,8 @@ class PithosClient(TestCase):
         tmpFile.seek(0)
         ctype = 'video/mpeg'
         sharing = dict(read=['u1', 'g1', 'u2'], write=['u1'])
-        r = self.client.upload_object(obj, tmpFile,
+        r = self.client.upload_object(
+            obj, tmpFile,
             content_type=ctype, sharing=sharing)
         self.assert_dicts_are_equal(r, exp_headers)
         self.assertEqual(OP.mock_calls[-1][2]['content_type'], ctype)
@@ -1378,7 +1407,6 @@ class PithosClient(TestCase):
                 self.assertEqual(r, {})
         exp_args = dict(
             hashmap=True,
-            data_range=None,
             version=None,
             if_etag_match=None,
             if_etag_not_match=None,
@@ -1389,11 +1417,9 @@ class PithosClient(TestCase):
             if_match='if match',
             if_none_match='if non match',
             if_modified_since='some date here',
-            if_unmodified_since='some date here',
-            data_range='10-20')
+            if_unmodified_since='some date here')
         with patch.object(
-                pithos.PithosClient, 'object_get',
-                return_value=FR()) as get:
+                pithos.PithosClient, 'object_get', return_value=FR()) as get:
             r = self.client.get_object_hashmap(obj)
             self.assertEqual(r, object_hashmap)
             self.assertEqual(get.mock_calls[-1], call(obj, **exp_args))
@@ -1810,5 +1836,8 @@ if __name__ == '__main__':
     if not argv[1:] or argv[1] == 'PithosRestClient':
         not_found = False
         runTestCase(PithosRestClient, 'PithosRest Client', argv[2:])
+    if not argv[1:] or argv[1] == 'PithosMethods':
+        not_found = False
+        runTestCase(PithosRestClient, 'Pithos Methods', argv[2:])
     if not_found:
         print('TestCase %s not found' % argv[1])
